==> tensorflow_federated-0.12.0-py2.py3-none-any.whl: tensorflow_federated/python/core/impl/context_stack/context_stack_impl.py <==
# Lint as: python3
# Copyright 2018, The TensorFlow Federated Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Defines classes/functions to manipulate the API context stack."""

import contextlib
import threading

from tensorflow_federated.python.common_libs import py_typecheck
from tensorflow_federated.python.core.impl import context_base
from tensorflow_federated.python.core.impl import context_stack_base
from tensorflow_federated.python.core.impl import execution_context
from tensorflow_federated.python.core.impl import executor_stacks


def _make_default_context():
  return execution_context.ExecutionContext(
      executor_stacks.local_executor_factory())


class ContextStackImpl(context_stack_base.ContextStack, threading.local):
  """An implementation of a common thread-local context stack to run against."""

  def __init__(self):
    super().__init__()
    self._stack = [_make_default_context()]

  def set_default_context(self, ctx=None):
    """Places `ctx` at the bottom of the stack.

    Args:
      ctx: Either an instance of `context_base.Context`, or `None`, with the
        latter resulting in the default reference executor getting installed at
        the bottom of the stack (as is the default).
    """
    if ctx is not None:
      py_typecheck.check_type(ctx, context_base.Context)
    else:
      ctx = _make_default_context()
    assert self._stack
    self._stack[0] = ctx

  @property
  def current(self):
    assert self._stack
    ctx = self._stack[-1]
    assert isinstance(ctx, context_base.Context)
    return ctx

  @contextlib.contextmanager
  def install(self, ctx):
    py_typecheck.check_type(ctx, context_base.Context)
    self._stack.append(ctx)
    try:
      yield ctx
    finally:
      self._stack.pop()


context_stack = ContextStackImpl()

==> tensorflow_federated-0.13.1-py2.py3-none-any.whl: tensorflow_federated/python/core/impl/context_stack/context_stack_impl.py <==
# Lint as: python3
# Copyright 2018, The TensorFlow Federated Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Defines classes/functions to manipulate the API context stack."""

import contextlib
import threading

from tensorflow_federated.python.common_libs import py_typecheck
from tensorflow_federated.python.core.impl import context_base
from tensorflow_federated.python.core.impl import context_stack_base
from tensorflow_federated.python.core.impl.executors import execution_context
from tensorflow_federated.python.core.impl.executors import executor_stacks


class ContextStackImpl(context_stack_base.ContextStack, threading.local):
  """An implementation of a common thread-local context stack to run against."""

  def __init__(self, default_context):
    super().__init__()
    self._stack = [default_context]

  def set_default_context(self, ctx):
    """Places `ctx` at the bottom of the stack.

    Args:
      ctx: An instance of `context_base.Context`.
    """
    py_typecheck.check_type(ctx, context_base.Context)
    assert self._stack
    self._stack[0] = ctx

  @property
  def current(self):
    assert self._stack
    ctx = self._stack[-1]
    assert isinstance(ctx, context_base.Context)
    return ctx

  @contextlib.contextmanager
  def install(self, ctx):
    py_typecheck.check_type(ctx, context_base.Context)
    self._stack.append(ctx)
    try:
      yield ctx
    finally:
      self._stack.pop()


context_stack = ContextStackImpl(
    execution_context.ExecutionContext(
        executor_stacks.local_executor_factory()))
